<?php 

/*
Plugin Name: Flickr-stream	
Plugin URI: http://www.codeclouds.net/flickrstream/
Description: This plugin allows you to include photosets and gallerys from Flickr in your wordpress site, either embedded into a page or post, or as a sidebar widget
Version: 1.2
Author: Dustin Scarberry
Author URI: http://www.codeclouds.net/
License: GPL2
*/

/*  2013 Dustin Scarberry webmaster@codeclouds.net

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if(!class_exists('flickrStream'))
{

	class flickrStream
	{
	
		private $_admin, $_frontend;
	
		public function __construct()
		{

			//load external files
			$this->load_dependencies();
		
			//activation hook
			register_activation_hook(__FILE__, array(&$this, 'activate'));
			
			//include photo widget
			require_once 'photos_widget.php';
			add_action('widgets_init', array(&$this, 'setup_widgets'));
			
		}
		
		//activate plugin
		public function activate()
		{
		
			$this->maintenance();
		
		}
		
		//load dependencies for plugin
		private function load_dependencies()
		{
		
			load_plugin_textdomain('flickrstm', false, 'flickr-stream/language');
			
			$this->upgrade_check();
		
			//load backend or frontend dependencies
			if(is_admin())
			{
			
				require dirname(__FILE__) . '/admin.php';
				$this->_admin = new fsAdmin();

			}
			else
			{
			
				require_once dirname(__FILE__) . '/frontend.php';
				$this->_frontend = new fsFrontend();
			
			}
		
		}
		
		private function maintenance()
		{
		
			//set up main option defaults if needed//
			$main = get_option('flickrstream_main_opts');
				
			if(empty($main))
				$main = array();
				
			$dft['apikey'] = '';
			$dft['marker'] = 1;
			$dft['fancyboxInc'] = 'no';
			$dft['useMobileView'] = 'no';
			$dft['version'] = '1.2';
				
			$opts = $main + $dft;
				
			update_option('flickrstream_main_opts', $opts);
		
		}
		
		private function upgrade_check()
		{
		
			$main = get_option('flickrstream_main_opts');
		
			if($main['version'] == null || $main['version'] < 1.2){
			
				$this->maintenance();
				$main['version'] = '1.2';
				update_option('flickrstream_main_opts', $main);
				
			}
		
		}
		
		public function setup_widgets()
		{
		
			register_widget('Flickrstream_Widget');
		
		}
		
	}

	$fsPlugin = new flickrStream();

}
?>